/*
 * SPY.CMD  by mira308sw
 *
 * Copy SPY data to USB and clear /I/SPY
 *
 * version:
 * 01.00: 21/09/2009
 */


/* Functions and data types from Integrated C Interpreter
 */
typedef unsigned char           BYTE;
typedef unsigned short          WORD;
typedef unsigned long           DWORD;

typedef int                     BOOL;

typedef void                    DIR;
typedef void                    FILE;

typedef enum { ERROR=-1,OK=0 }  STATUS;

#define NULL                    (void*)0
#define TRUE                    1
#define FALSE                   0

int     atoi                    ( char *s );
STATUS  close                   ( int hf );
STATUS  closedir                ( DIR *d );
STATUS  EiC_ExeFile             ( int argc,char **argv );
STATUS  fclose                  ( FILE *f );
STATUS  feof                    ( FILE *f );
char*   fgets                   ( char *s,int max,FILE *f );
FILE*   fopen                   ( char *fn,char *mode );
STATUS  fputs                   ( char *s,FILE *f );
void    free                    ( void *mem );
void    loadModule              ( int hf,int mode );
STATUS  logMsg                  ( char *fmt,...);
void*   malloc                  ( int size );
STATUS  mv                      ( char *src,char *dest );
int     open                    ( char *fn,int access,int mode );
DIR*    opendir                 ( char *dn );
int     putchar                 ( int c );
char*   strcat                  ( char *dest,char *s );
int     strcmp                  ( char *s1,char *s2 );
char*   strcpy                  ( char *dest,char *src );
int     strlen                  ( char *s );
int     strncmp                 ( char *s1,char *s2,int max );
char*   strrchr                 ( char *s,int c );
char*   strstr                  ( char *s1,char *s2 );
void    taskDelay               ( int tick );
DWORD   tickGet                 ( void );
STATUS  xcopy                   ( char *src,char *dest );
STATUS  xdelete                 ( char *src );

/* functions not yet known (for me)
 *
void    copy                    ( void );
void    creat                   ( void );
void    ExeScriptFile           ( void );
void    moduleFindByNameAndPath ( void );
void    rm                      ( void );
void    sqrt                    ( void );
void    symFindByNameAndType    ( void );
void    unldByModuleId          ( void );
void    unldByNameAndPath       ( void );
 */

/* Funcions and data type from modified builtins.out crc=19bb6041
 */

#define LOAD_NO_SYMBOLS         2
#define LOAD_LOCAL_SYMBOLS      4
#define LOAD_GLOBAL_SYMBOLS     8
#define LOAD_ALL_SYMBOLS        (LOAD_LOCAL_SYMBOLS|LOAD_GLOBAL_SYMBOLS)

void    AddGatewayHistory         ( void );
STATUS  AddUPGHistoryHeader       ( char *cd,char *target,char *action );
STATUS  BootRomFormatTffs         ( void );
void    CheckCRCDrive             ( void );
STATUS  CheckCRCFile              ( char *fn );
STATUS  ComputeCRCFile            ( char *fn,char *crc);
STATUS  EnableHistoryHandler      ( int on );
STATUS  EnableSetPowerOffHandler  ( int on );
int     Execute                   ( void *funptr );
int     ExecuteFlasherOut         ( void *funptr,... );   // max 7 parameters
void    Format                    ( void );
STATUS  GetBootromVersion         ( char *ver );
STATUS  GetCDVersion              ( char *ver );
STATUS  GetCurrentDateClock       ( char *dc );
STATUS  GetModuleId               ( int mid,char *tid );
STATUS  GetSearchResult           ( int ndx,char *res,char *path );
STATUS  GetSourceDrive            ( char *path );
STATUS  InstallHDDTestFiles       ( void );
int     IsFpInLoader              ( void );
int     IsPartitionCaseSensitive  ( void );
int     IsPartitionUnderRepair    ( void );
void    loadFile                  ( void );
STATUS  LockCDEject               ( int on );
STATUS  ReadFileCRC               ( char *fn,char *crc );
void    RebootSystem              ( void );
int     SearchAndTargetFileExclu  ( char *fn,char *tn,char *par[],int npar,char *root,char *dir );
STATUS  SetBootLoaderFlag         ( int stayInBootLoader );
STATUS  SetMasterFlashingOn       ( void );
STATUS  SetPartitionRepairState   ( int repair );
STATUS  SetPower                  ( int on );
STATUS  SetRedLedOn               ( int on );
STATUS  SetUPGInProgressInCDD     ( int on );
STATUS  SetUpgradeLogging         ( int on );
STATUS  StopCOMModule             ( int mid );
STATUS  StopHDDActivity           ( void );
STATUS  UpdateFSImage             ( void );
STATUS  UPGCopy                   ( char *src,char *dst,int cut );
STATUS  UPGDelete                 ( char *fn );
void*   UPGFindSymbol             ( char *sym );
STATUS  UPGLogMsg                 ( char *fmt,... );

/* Functions and data types from MMI module
 */
#define NO                            0
#define YES                           1

STATUS  ClearScreen                   ( void );
STATUS  ShowNavigationBargraph        ( void );
STATUS  StepBargraph                  ( char *txt, int per );
STATUS  ShowNavigationQuestionScreen  ( char *txt, int *answ );

/* Functions and data types for RTx system
 */
// Drive letters
#define DRIVE_USB       "/bd0"
#define DRIVE_HDD       "/C"
#define DRIVE_CD        "/D"
#define DRIVE_TFFS      "/F"
#define DRIVE_NAV       "/H"
#define DRIVE_USER      "/I"
#define DRIVE_JBX       "/J"


/* Other builtins Functions and data type
 */
int     UPGSearchFile       ( char *fn, char *root, char *param, char *tabledir );
STATUS  UPGGetSearchResult  ( int ndx,char *res );
STATUS  UPGMKDir            ( char *dir);
STATUS  UPGMKDelete         ( char *dir);
STATUS  GetFileSize         ( char *fn, int *size);





/****************************** SPY.CMD ******************************/

#define SPY_PATH    DRIVE_USER "/SPY"


char* _strchr ( char *p_s,char p_c )
{
  for( ; *p_s ; p_s++ )
    if( *p_s==p_c )
      return p_s;
  return NULL;
}

int   MakeDir ( char *p_sPath )
{
  char  *l_p=_strchr( p_sPath+1,'/' );
  for( l_p=_strchr( l_p+1,'/' ) ; l_p ; l_p=_strchr( l_p+1,'/' ) )
  {
    *l_p=0;
    if( UPGMKDir( p_sPath )!=OK )
      return ERROR;
    *l_p='/';
  }
  return UPGMKDir( p_sPath );
}

int  main ( int argc, char **argv )
{
  int   l_iAnsw = FALSE;
  int   l_iCopyAll;
  int   l_iCopy;
  int   l_nFile;
  int   l_i;
  char  l_sFile[256];
  char  l_sPath[256];

  ShowNavigationQuestionScreen( "Copy ALL spy data ?",&l_iCopyAll );
  ShowNavigationBargraph();
  StepBargraph( "Searching spy data",0 );
  l_nFile=UPGSearchFile( "*.*",SPY_PATH,NULL,NULL );
  for( l_i=0 ; l_i<l_nFile ; l_i++ )
  {
    if( UPGGetSearchResult( l_i,l_sFile )==ERROR )
      continue;
    *strrchr( l_sFile,'/' )=0;
    if( strcmp( l_sFile,l_sPath )==0 )
      continue;
    if( l_iCopyAll )
      l_iCopy=YES;
    else
    {
      strcpy( l_sPath,"Copy " );
      strcat( l_sPath,strrchr( l_sFile,'/' ) );
      strcat( l_sPath," ?" );
      ShowNavigationQuestionScreen( l_sPath,&l_iCopy );
    }
    if( l_iCopy )
    {
      ShowNavigationBargraph();
      StepBargraph( "Coping...",100*l_i/l_nFile );
      strcpy( l_sPath,DRIVE_USB );
      strcat( l_sPath,l_sFile+strlen( DRIVE_USER ) );
      MakeDir( l_sPath );
      if( xcopy( l_sFile,l_sPath )!=OK )
      {
        strcpy( l_sPath,"ERROR coping " );
        strcat( l_sPath,l_sFile );
        ShowNavigationQuestionScreen( l_sPath,&l_iAnsw );
      }
    }
    strcpy( l_sPath,"Delete " );
    strcat( l_sPath,strrchr( l_sFile,'/' ) );
    strcat( l_sPath," ?" );
    ShowNavigationQuestionScreen( l_sPath,&l_iAnsw );
    if( l_iAnsw==YES )
    {
      ShowNavigationBargraph();
      StepBargraph( "Delete...",100*l_i/l_nFile );
      if( xdelete( l_sFile )!=OK )
      {
        strcpy( l_sPath,"ERROR deleting " );
        strcat( l_sPath,l_sFile );
        ShowNavigationQuestionScreen( l_sPath,&l_iAnsw );
      }
    }
    strcpy( l_sPath,l_sFile );
  }
  ShowNavigationQuestionScreen( "Copy completed!",&l_iAnsw );

  ClearScreen();
  return OK;
}

